@@ -1717,6 +1717,9 @@ _thunar_tree_view_model_cancel_search_job (ThunarTreeViewModel *model)
       g_object_unref (model->search_job);
       model->search_job = NULL;
     }
+
+  thunar_g_list_free_full (model->search_files);
+  model->search_files = NULL;
 }
 
 
@@ -2516,10 +2519,26 @@ thunar_tree_view_model_sort (ThunarTreeViewModel *model)
 static void
 _thunar_tree_view_model_folder_destroy (Node *node)
 {
-  /* if a subdir get's destroyed it's handled internally but if the current_folder
-   * get's destroyed then we simply set_folder to NULL & cleanup things */
+  /* if a subdir gets destroyed, it's handled internally, but if the current_folder
+   * gets destroyed, then we simply set_folder to NULL & cleanup things */
   if (node->parent == NULL)
-    thunar_tree_view_model_set_folder (THUNAR_STANDARD_VIEW_MODEL (node->model), NULL, NULL);
+    {
+      if (node->n_children > 0)
+        {
+          /* set_folder func does not emit row-deleted signal, but instead relies on
+           * ThunarStandardView to disconnect & reconnect the view to quickly update
+           * changes in current_directory. */
+          GList *keys = g_hash_table_get_keys (node->set);
+
+          for (GList *lp = keys; lp != NULL; lp = lp->next)
+            thunar_tree_view_model_dir_remove_file (node, THUNAR_FILE (lp->data));
+
+          g_list_free (keys);
+        }
+
+      /* reset the model */
+      thunar_tree_view_model_set_folder (THUNAR_STANDARD_VIEW_MODEL (node->model), NULL, NULL);
+    }
 }
 
 
@@ -2530,26 +2549,13 @@ _thunar_tree_view_model_folder_error (Node         *node,
 {
   _thunar_return_if_fail (error != NULL);
 
-  if (node->n_children > 0)
-    {
-      if (node->parent == NULL)
-        {
-          /* set_folder func does not emit row-deleted signal instead relies
-           * on ThunarStandardView to disconnect & reconnect the view quickly update
-           * changes in current_directory. */
-          GList *keys = g_hash_table_get_keys (node->set);
+  if (node->parent == NULL)
+    _thunar_tree_view_model_folder_destroy (node);
+  else
+    thunar_tree_view_model_dir_remove_file (node->parent, node->file);
 
-          for (GList *lp = keys; lp != NULL; lp = lp->next)
-            thunar_tree_view_model_dir_remove_file (node, THUNAR_FILE (lp->data));
-
-          g_list_free (keys);
-
-          /* reset the model if error is with the current directory */
-          thunar_tree_view_model_set_folder (THUNAR_STANDARD_VIEW_MODEL (node->model), NULL, NULL);
-        }
-      else
-        thunar_tree_view_model_dir_remove_file (node->parent, node->file);
-    }
+  /* forward the error signal */
+  g_signal_emit_by_name (G_OBJECT (node->model), "error", error);
 }
 
 
@@ -2578,6 +2584,8 @@ _thunar_tree_view_model_dir_files_added (Node       *node,
       if (!g_hash_table_contains (node->set, file))
         thunar_tree_view_model_dir_add_file (node, file);
     }
+
+  g_object_notify_by_pspec (G_OBJECT (node->model), tree_model_props[PROP_NUM_FILES]);
 }
 
 
@@ -2607,6 +2615,8 @@ _thunar_tree_view_model_dir_files_removed (Node       *node,
 
       thunar_tree_view_model_dir_remove_file (node, file);
     }
+
+  g_object_notify_by_pspec (G_OBJECT (node->model), tree_model_props[PROP_NUM_FILES]);
 }
 
 
@@ -3114,9 +3124,12 @@ thunar_tree_view_model_update_search_files (ThunarTreeViewModel *model)
       g_object_unref (file);
     }
 
+  g_object_notify_by_pspec (G_OBJECT (model), tree_model_props[PROP_NUM_FILES]);
+
   if (model->search_files != NULL)
-    g_list_free (model->search_files);
+    thunar_g_list_free_full (model->search_files);
   model->search_files = NULL;
+
   g_mutex_unlock (&model->mutex_add_search_files);
 
   return TRUE;
